# Cross-sectional checks

Cross-sectional checks operate on the materialised universe-anchored snapshot.

::: dqf.NullRateCheck

::: dqf.NotNullCheck

::: dqf.CardinalityCheck

::: dqf.OutlierCheck

::: dqf.RangeCheck

::: dqf.UniquenessCheck

::: dqf.AllowedValuesCheck

::: dqf.RegexPatternCheck

::: dqf.ReferentialIntegrityCheck
